@@ -1,18 +1,24 @@
 from ape import plugins
 
-from .providers import AlchemyEthereumProvider
+from .provider import Alchemy
 
 NETWORKS = {
     "ethereum": [
         "mainnet",
-        "ropsten",
-        "rinkeby",
-        "kovan",
         "goerli",
+        "sepolia",
     ],
     "arbitrum": [
         "mainnet",
-        "testnet",
+        "goerli",
+    ],
+    "optimism": [
+        "mainnet",
+        "goerli",
+    ],
+    "polygon": [
+        "mainnet",
+        "mumbai",
     ],
 }
 
@@ -21,4 +27,4 @@ NETWORKS = {
 def providers():
     for ecosystem_name in NETWORKS:
         for network_name in NETWORKS[ecosystem_name]:
-            yield ecosystem_name, network_name, AlchemyEthereumProvider
+            yield ecosystem_name, network_name, Alchemy
