@@ -6,7 +6,7 @@ from ape.types import LogFilter
 from hexbytes import HexBytes
 from web3.exceptions import ContractLogicError as Web3ContractLogicError
 
-from ape_alchemy.providers import AlchemyFeatureNotAvailable, MissingProjectKeyError
+from ape_alchemy.provider import AlchemyFeatureNotAvailable, MissingProjectKeyError
 
 TXN_HASH = "0x3cef4aaa52b97b6b61aa32b3afcecb0d14f7862ca80fdc76504c37a9374645c4"
 
@@ -111,12 +111,18 @@ def receipt():
 def test_when_no_api_key_raises_error(missing_token, alchemy_provider):
     with pytest.raises(
         MissingProjectKeyError,
-        match=re.escape("Must set one of $WEB3_ALCHEMY_PROJECT_ID, $WEB3_ALCHEMY_API_KEY."),
+        match=re.escape(
+            "Must set one of "
+            "$WEB3_ALCHEMY_PROJECT_ID, "
+            "$WEB3_ALCHEMY_API_KEY, "
+            "$WEB3_ETHEREUM_GOERLI_ALCHEMY_PROJECT_ID, "
+            "$WEB3_ETHEREUM_GOERLI_ALCHEMY_API_KEY."
+        ),
     ):
         alchemy_provider.connect()
 
 
-def test_send_transaction_reverts(token, alchemy_provider, mock_web3, mock_transaction):
+def test_send_transaction_reverts(token, alchemy_provider, mock_web3, transaction):
     expected_revert_message = "EXPECTED REVERT MESSAGE"
     mock_web3.eth.send_raw_transaction.side_effect = Web3ContractLogicError(
         f"execution reverted : {expected_revert_message}"
@@ -124,18 +130,18 @@ def test_send_transaction_reverts(token, alchemy_provider, mock_web3, mock_trans
     alchemy_provider._web3 = mock_web3
 
     with pytest.raises(ContractLogicError, match=expected_revert_message):
-        alchemy_provider.send_transaction(mock_transaction)
+        alchemy_provider.send_transaction(transaction)
 
 
-def test_send_transaction_reverts_no_message(token, alchemy_provider, mock_web3, mock_transaction):
+def test_send_transaction_reverts_no_message(token, alchemy_provider, mock_web3, transaction):
     mock_web3.eth.send_raw_transaction.side_effect = Web3ContractLogicError("execution reverted")
     alchemy_provider._web3 = mock_web3
 
     with pytest.raises(ContractLogicError, match="Transaction failed."):
-        alchemy_provider.send_transaction(mock_transaction)
+        alchemy_provider.send_transaction(transaction)
 
 
-def test_estimate_gas_would_revert(token, alchemy_provider, mock_web3, mock_transaction):
+def test_estimate_gas_would_revert(token, alchemy_provider, mock_web3, transaction):
     expected_revert_message = "EXPECTED REVERT MESSAGE"
     mock_web3.eth.estimate_gas.side_effect = Web3ContractLogicError(
         f"execution reverted : {expected_revert_message}"
@@ -143,15 +149,15 @@ def test_estimate_gas_would_revert(token, alchemy_provider, mock_web3, mock_tran
     alchemy_provider._web3 = mock_web3
 
     with pytest.raises(ContractLogicError, match=expected_revert_message):
-        alchemy_provider.estimate_gas_cost(mock_transaction)
+        alchemy_provider.estimate_gas_cost(transaction)
 
 
-def test_estimate_gas_would_revert_no_message(token, alchemy_provider, mock_web3, mock_transaction):
+def test_estimate_gas_would_revert_no_message(token, alchemy_provider, mock_web3, transaction):
     mock_web3.eth.estimate_gas.side_effect = Web3ContractLogicError("execution reverted")
     alchemy_provider._web3 = mock_web3
 
     with pytest.raises(ContractLogicError, match="Transaction failed."):
-        alchemy_provider.estimate_gas_cost(mock_transaction)
+        alchemy_provider.estimate_gas_cost(transaction)
 
 
 def test_feature_not_available(
@@ -182,5 +188,5 @@ def test_get_call_tree(networks, alchemy_provider, mock_web3, parity_trace, rece
     alchemy_provider._web3 = mock_web3
     networks.active_provider = alchemy_provider
     actual = repr(alchemy_provider.get_call_tree(TXN_HASH))
-    expected = "CALL: 0xC17f2C69aE2E66FD87367E3260412EEfF637F70E.<0x96d373e5> [1401584 gas]"
-    assert actual == expected
+    expected = r"0xC17f2C69aE2E66FD87367E3260412EEfF637F70E\.0x96d373e5\(\) \[1401584 gas\]"
+    assert re.match(expected, actual)
